
% (Un)Availability values for Protected DPT (2 DPT). - Block Diagram
% 32 wavelengths, 32+2 DPTs.
clear all;
format long;

% Number of wavelengths
M = 32;

% Fixed values for Availability
Amux_fix = 0.9999952;               % [39] based on [40]
Aswitch_fix = 0.9999996;            % High utilization of... [52]
Asplit_fix = 0.9999999;             % High Utilization of... [52]
Adpt_fix = 0.99998;                 % Calculated

% Variable values
Umux = [1e-7, 1e-6, 1e-5, 1e-4, 1e-3, 1e-2];
Uswitch = [1e-7, 1e-6, 1e-5, 1e-4, 1e-3, 1e-2];
Usplit = [1e-7, 1e-6, 1e-5, 1e-4, 1e-3, 1e-2];
Udpt = [1e-7, 1e-6, 1e-5, 1e-4, 1e-3, 1e-2];
Amux = 1 - Umux;
Aswitch = 1 - Uswitch;
Asplit = 1 - Usplit;
Adpt = 1 - Udpt;

% Availabilities for the 5 models
A2p_mux = zeros(1,6);
A2p_switch = zeros(1,6);
A2p_split = zeros(1,6);
A2p_dpt = zeros(1,6);
A2p = zeros(1,6);

% Reference availability
As_dpt_fix = ((Asplit_fix)^(M-1)) * Adpt_fix * ((Asplit_fix)^(3*(M-1)));
Adpt_system_fix = (((Adpt_fix)^M)*((As_dpt_fix)^2)) + (M*(1-Adpt_fix)*((Adpt_fix)^(M-1))*((As_dpt_fix)^2)) + ((nchoosek(M,2))*((1-Adpt_fix)^2)*((Adpt_fix)^(M-2))*((As_dpt_fix)^2)) + 2*(((Adpt_fix)^M)*(1-As_dpt_fix)*As_dpt_fix) + (((Adpt_fix)^M)*((1-As_dpt_fix)^2)) + 2*(M*(1-Adpt_fix)*((Adpt_fix)^(M-1))*As_dpt_fix*(1-As_dpt_fix)); 

A2p(1,:) = Amux_fix * (Aswitch_fix^M) * Adpt_system_fix * (Aswitch_fix^(M*3));
U2p = 1 - A2p;

% Availabilities varying Amux, Aswitch, Asplit, Adpt.
A2p_mux = Amux .* (Aswitch_fix^M) * Adpt_system_fix * (Aswitch_fix^(M*3));
A2p_switch = Amux_fix .* (Aswitch.^M) .* Adpt_system_fix .* (Aswitch.^(M*3));

As_dpt_split = ((Asplit).^(M-1)) .* Adpt_fix .* ((Asplit).^(3*(M-1)));
Adpt_system_split = (((Adpt_fix)^M)*((As_dpt_split).^2)) + (M*(1-Adpt_fix)*((Adpt_fix)^(M-1))*((As_dpt_split).^2)) + ((nchoosek(M,2))*((1-Adpt_fix)^2)*((Adpt_fix)^(M-2))*((As_dpt_split).^2)) + 2*(((Adpt_fix)^M).*(1-As_dpt_split).*As_dpt_split) + (((Adpt_fix)^M)*((1-As_dpt_split).^2)) + 2*(M*(1-Adpt_fix)*((Adpt_fix)^(M-1)).*As_dpt_split.*(1-As_dpt_split));
A2p_split = Amux_fix .* (Aswitch_fix^M) .* Adpt_system_split .* (Aswitch_fix^(M*3));

As_dpt_dpt = ((Asplit_fix)^(M-1)) .* Adpt .* ((Asplit_fix)^(3*(M-1)));
Adpt_system_dpt = (((Adpt).^M).*((As_dpt_dpt).^2)) + (M.*(1-Adpt).*((Adpt).^(M-1)).*((As_dpt_dpt).^2)) + ((nchoosek(M,2)).*((1-Adpt).^2).*((Adpt).^(M-2)).*((As_dpt_dpt).^2)) + 2*(((Adpt).^M).*(1-As_dpt_dpt).*As_dpt_dpt) + (((Adpt).^M).*((1-As_dpt_dpt).^2)) + 2*(M.*(1-Adpt).*((Adpt).^(M-1)).*As_dpt_dpt.*(1-As_dpt_dpt));
A2p_dpt = Amux_fix .* (Aswitch_fix^M) .* Adpt_system_dpt .* (Aswitch_fix^(M*3));

U2p_mux = 1 - A2p_mux;
U2p_switch = 1 - A2p_switch;
U2p_split = 1 - A2p_split;
U2p_dpt = 1 - A2p_dpt;

% Figure
figure
plot(Umux, U2p_mux, 'k.-');
hold on
plot(Uswitch, U2p_switch, 'mo-');
hold on
plot(Usplit, U2p_split, 'y*-');
hold on
plot(Udpt, U2p_dpt, 'bs-');
hold on
plot(Udpt, U2p, 'rs-');
hold on

title('Unavailability for Protected DPT (2 Backup DPTs) Architecture. - Block Diagram');
xlabel('Umux, Uswitch, Usplit, Udpt');
ylabel('Unavailability');
legend('x axis = Umux', 'x axis = Uswitch', 'x axis = Usplit', 'x axis = Udpt', 'Reference = 5.6e-5');
hold off
grid on;