
% (Un)Availability values for Group Protected DPT. - Block Diagram
% 32 wavelengths, 32 DPTs + 2 protection.
% 1 spare DPT for the first 16 DPTs, and another spare DPT for the other 16 DPTs
clear all;
format long;

% Number of wavelengths
M = 32;
groups = 2;
DPT_group = M/groups;

% Fixed values for Availability
Amux_fix = 0.9999952;               % [39] based on [40]
Aswitch_fix = 0.9999996;            % High utilization of... [52]
Asplit_fix = 0.9999999;             % High Utilization of... [52]
Adpt_fix = 0.99998;                 % Calculated

% Variable values
Umux = [1e-7, 1e-6, 1e-5, 1e-4, 1e-3, 1e-2];
Uswitch = [1e-7, 1e-6, 1e-5, 1e-4, 1e-3, 1e-2];
Usplit = [1e-7, 1e-6, 1e-5, 1e-4, 1e-3, 1e-2];
Udpt = [1e-7, 1e-6, 1e-5, 1e-4, 1e-3, 1e-2];
Amux = 1 - Umux;
Aswitch = 1 - Uswitch;
Asplit = 1 - Usplit;
Adpt = 1 - Udpt;

% Availabilities for the 5 models
Agp_mux = zeros(1,6);
Agp_switch = zeros(1,6);
Agp_split = zeros(1,6);
Agp_dpt = zeros(1,6);
Agp = zeros(1,6);

% Reference availability
As_dpt_fix = ((Asplit_fix)^(DPT_group-1)) * Adpt_fix * ((Asplit_fix)^(3*(DPT_group-1)));
Adpt_system_fix = (((Adpt_fix)^DPT_group)*As_dpt_fix) + (DPT_group*(1-Adpt_fix)*((Adpt_fix)^(DPT_group-1))*As_dpt_fix) + (((Adpt_fix)^DPT_group)*(1-As_dpt_fix)); 

Agp(1,:) = Amux_fix * (Aswitch_fix^M) * Adpt_system_fix^groups * (Aswitch_fix^(M*3));
Ugp = 1 - Agp;

% Availabilities varying Amux, Aswitch, Asplit, Adpt.
Agp_mux = Amux .* (Aswitch_fix^M) * Adpt_system_fix^groups * (Aswitch_fix^(M*3));
Agp_switch = Amux_fix .* (Aswitch.^M) .* Adpt_system_fix^groups .* (Aswitch.^(M*3));

As_dpt_split = ((Asplit).^(DPT_group-1)) .* Adpt_fix .* ((Asplit).^(3*(DPT_group-1)));
Adpt_system_split = (((Adpt_fix)^DPT_group).*As_dpt_split) + (DPT_group*(1-Adpt_fix)*((Adpt_fix)^(DPT_group-1)).*As_dpt_split) + (((Adpt_fix)^DPT_group).*(1-As_dpt_split)); 
Agp_split = Amux_fix .* (Aswitch_fix^M) .* (Adpt_system_split.^groups) .* (Aswitch_fix^(M*3));

As_dpt_dpt = ((Asplit_fix)^(DPT_group-1)) .* Adpt .* ((Asplit_fix)^(3*(DPT_group-1)));
Adpt_system_dpt = (((Adpt).^DPT_group).*As_dpt_dpt) + (DPT_group.*(1-Adpt).*((Adpt).^(DPT_group-1)).*As_dpt_dpt) + (((Adpt).^DPT_group).*(1-As_dpt_dpt));
Agp_dpt = Amux_fix .* (Aswitch_fix^M) .* (Adpt_system_dpt.^groups) .* (Aswitch_fix^(M*3));

Ugp_mux = 1 - Agp_mux;
Ugp_switch = 1 - Agp_switch;
Ugp_split = 1 - Agp_split;
Ugp_dpt = 1 - Agp_dpt;

% Figure
figure
plot(Umux, Ugp_mux, 'k.-');
hold on
plot(Uswitch, Ugp_switch, 'mo-');
hold on
plot(Usplit, Ugp_split, 'y*-');
hold on
plot(Udpt, Ugp_dpt, 'bs-');
hold on
plot(Udpt, Ugp, 'rs-');
hold on

title('Unavailability for Protected DPT (Groups) Architecture. - Block Diagram');
xlabel('Umux, Uswitch, Usplit, Udpt');
ylabel('Unavailability');
legend('x axis = Umux', 'x axis = Uswitch', 'x axis = Usplit', 'x axis = Udpt', 'Reference = 5.611e-5');
hold off
grid on;
