
% (Un)Availability values for Protected DPT. - Block Diagram
% 32 wavelengths, 32+1 DPTs.
clear all;
format long;

% Number of wavelengths
M = 32;

% Fixed values for Availability
Amux_fix = 0.9999952;               % [39] based on [40]
Aswitch_fix = 0.9999996;            % High utilization of... [52]
Asplit_fix = 0.9999999;             % High Utilization of... [52]
Adpt_fix = 0.99998;                 % Calculated

% Variable values
Umux = [1e-7, 1e-6, 1e-5, 1e-4, 1e-3, 1e-2];
Uswitch = [1e-7, 1e-6, 1e-5, 1e-4, 1e-3, 1e-2];
Usplit = [1e-7, 1e-6, 1e-5, 1e-4, 1e-3, 1e-2];
Udpt = [1e-7, 1e-6, 1e-5, 1e-4, 1e-3, 1e-2];
Amux = 1 - Umux;
Aswitch = 1 - Uswitch;
Asplit = 1 - Usplit;
Adpt = 1 - Udpt;

% Availabilities for the 5 models
Ap_mux = zeros(1,6);
Ap_switch = zeros(1,6);
Ap_split = zeros(1,6);
Ap_dpt = zeros(1,6);
Ap = zeros(1,6);

% Reference availability
As_dpt_fix = ((Asplit_fix)^(M-1)) * Adpt_fix * ((Asplit_fix)^(3*(M-1)));
Adpt_system_fix = (((Adpt_fix)^M)*As_dpt_fix) + (M*(1-Adpt_fix)*((Adpt_fix)^(M-1))*As_dpt_fix) + (((Adpt_fix)^M)*(1-As_dpt_fix)); 

Ap(1,:) = Amux_fix * (Aswitch_fix^M) * Adpt_system_fix * (Aswitch_fix^(M*3));
Up = 1 - Ap;

% Availabilities varying Amux, Aswitch, Asplit, Adpt
Ap_mux = Amux .* (Aswitch_fix^M) * Adpt_system_fix * (Aswitch_fix^(M*3));
Ap_switch = Amux_fix .* (Aswitch.^M) .* Adpt_system_fix .* (Aswitch.^(M*3));

As_dpt_split = ((Asplit).^(M-1)) .* Adpt_fix .* ((Asplit).^(3*(M-1)));
Adpt_system_split = (((Adpt_fix)^M).*As_dpt_split) + (M*(1-Adpt_fix)*((Adpt_fix)^(M-1)).*As_dpt_split) + (((Adpt_fix)^M).*(1-As_dpt_split)); 
Ap_split = Amux_fix .* (Aswitch_fix^M) .* Adpt_system_split .* (Aswitch_fix^(M*3));

As_dpt_dpt = ((Asplit_fix)^(M-1)) .* Adpt .* ((Asplit_fix)^(3*(M-1)));
Adpt_system_dpt = (((Adpt).^M).*As_dpt_dpt) + (M.*(1-Adpt).*((Adpt).^(M-1)).*As_dpt_dpt) + (((Adpt).^M).*(1-As_dpt_dpt));
Ap_dpt = Amux_fix .* (Aswitch_fix^M) .* Adpt_system_dpt .* (Aswitch_fix^(M*3));

Up_mux = 1 - Ap_mux;
Up_switch = 1 - Ap_switch;
Up_split = 1 - Ap_split;
Up_dpt = 1 - Ap_dpt;

% Figure
figure
plot(Umux, Up_mux, 'k.-');
hold on
plot(Uswitch, Up_switch, 'mo-');
hold on
plot(Usplit, Up_split, 'y*-');
hold on
plot(Udpt, Up_dpt, 'bs-');
hold on
plot(Udpt, Up, 'rs-');
hold on

title('Unavailability for Protected DPT (1 Backup DPTs) Architecture. - Block Diagram');
xlabel('Umux, Uswitch, Usplit, Udpt');
ylabel('Unavailability');
legend('x axis = Umux', 'x axis = Uswitch', 'x axis = Usplit', 'x axis = Udpt', 'Reference = 5.622e-5');
hold off
grid on;
