
% (Un)Availability values for Unprotected DPT. - Block Diagram
% 32 wavelengths, 32 DPTs.
clear all;
format long;

% Number of wavelengths
M = 32;

% Fixed values for Availability
Amux_fix = 0.9999952;               % [39] based on [40]
Adpt_fix = 0.99998;                 % Calculated

% Variable values
Umux = [1e-7, 1e-6, 1e-5, 1e-4, 1e-3, 1e-2];
Udpt = [1e-7, 1e-6, 1e-5, 1e-4, 1e-3, 1e-2];
Amux = 1 - Umux;
Adpt = 1 - Udpt;

% Availabilities for the 3 models
Anop_mux = zeros(1,6);
Anop_dpt = zeros(1,6);
Anop = zeros(1,6);

% Reference Availability
Anop(1,:) = Amux_fix .* ((Adpt_fix).^M);
Unop = 1 - Anop;

% Availabilities varying Amux, Adpt
Anop_mux = Amux .* ((Adpt_fix)^M);
Anop_dpt = Amux_fix .* ((Adpt).^M);

Unop_mux = 1 - Anop_mux;
Unop_dpt = 1 - Anop_dpt;

% Figure
figure
plot(Umux, Unop_mux, 'k.-');
hold on
plot(Udpt, Unop_dpt, 'bo-');
hold on
plot(Udpt, Unop, 'rs-');
hold on

title('Unavailability for Unprotected DPT Architecture. - Block Diagram');
xlabel('Umux, Udpt');
ylabel('Unavailability');
legend('x axis = Umux', 'x axis = Udpt', 'Reference = 6.446e-4');
hold off
grid on;
