
% (Un)Availability values for Duplicated EPS - Block Diagram.
% No signaling between nodes
clear all;
format long;

% Number of wavelengths
M = 32;

% Fixed values for Availability
Amux_fix = 0.9999952;                   % [39] based on [40] 
Adpt_fix = 0.99998;                     % Calculated
Asplit_fix = 0.9999999;                 % High Utilization of... [52]
Aeps_fix = 0.999816;                    % Calculated
Aswitch_fix = 0.9999996;                % High Utilization of... [52]

Aepstot_fix = (1-(1-Aeps_fix)^2);
Ap_coup_fix = (1-(1-Asplit_fix)^M);

% Variable values
Umux = [1e-7, 1e-6, 1e-5, 1e-4, 1e-3, 1e-2];
Udpt = [1e-7, 1e-6, 1e-5, 1e-4, 1e-3, 1e-2];
Usplit = [1e-7, 1e-6, 1e-5, 1e-4, 1e-3, 1e-2];
Ueps = [1e-7, 1e-6, 1e-5, 1e-4, 1e-3, 1e-2];
Uswitch = [1e-7, 1e-6, 1e-5, 1e-4, 1e-3, 1e-2];
Amux = 1 - Umux;
Adpt = 1 - Udpt;
Asplit = 1 - Usplit;
Aeps = 1 - Ueps;
Aswitch = 1 - Uswitch;

Aepstot = (1-(1-Aeps).^2);
Ap_coup = (1-(1-Asplit).^M);

% Reference Availability
A1a = zeros(1,6);
A1a(1,:) = Amux_fix * Adpt_fix * Amux_fix * Asplit_fix * Aepstot_fix * Aswitch_fix * Amux_fix * Ap_coup_fix * Amux_fix;
U1a = 1 - A1a;

% Availabilities varying Amux, Adpt, Aspli, Aeps, Aswitch
A1a_mux = Amux .* Adpt_fix .* Amux .* Asplit_fix .* Aepstot_fix .* Aswitch_fix .* Amux .* Ap_coup_fix .* Amux;
A1a_dpt = Amux_fix .* Adpt .* Amux_fix * Asplit_fix * Aepstot_fix * Aswitch_fix * Amux_fix * Ap_coup_fix * Amux_fix;
A1a_split = Amux_fix * Adpt_fix * Amux_fix .* Asplit .* Aepstot_fix * Aswitch_fix * Amux_fix .* Ap_coup .* Amux_fix;
A1a_eps = Amux_fix * Adpt_fix * Amux_fix * Asplit_fix .* Aepstot .* Aswitch_fix * Amux_fix * Ap_coup_fix * Amux_fix;
A1a_switch = Amux_fix * Adpt_fix * Amux_fix * Asplit_fix * Aepstot_fix .* Aswitch .* Amux_fix * Ap_coup_fix * Amux_fix;

U1a_mux = 1 - A1a_mux;
U1a_dpt = 1 - A1a_dpt;
U1a_split = 1 - A1a_split;
U1a_eps = 1 - A1a_eps;
U1a_switch = 1 - A1a_switch;

%Figure
figure
plot(Umux, U1a_mux, 'bo-');
hold on;
plot(Udpt, U1a_dpt, 'cx-');
hold on;
plot(Usplit, U1a_split, 'ys-');
hold on;
plot(Ueps, U1a_eps, 'm*-');
hold on
plot(Uswitch, U1a_switch, 'k+-');
hold on
plot(Uswitch, U1a, 'rs-');
hold on;

title('Unavailability for Duplicated EPS - Block Diagram. No Communication Between Nodes');
xlabel('Umux, Udpt, Usplit, Ueps, Uswitch');
ylabel('Unavailability');
legend('x axis = Umux', 'x axis = Udpt', 'x axis = Usplit', 'x axis = Ueps', 'x axis = Uswitch', 'Reference = 3.971e-5');
hold off
grid on;
