% (Un)Availability values for Duplicated EPS - Markov Model.
% 1 DPT, 2 EPS.

points= 100; %Number of points
scale=linspace(1e-7, 1e-3, points); % Used to plot the reference line in figures

Avdeps = zeros(3,points);           % Row 1 stores reference value (all rates fixed)
Undeps = zeros(3,points);           % Row 2 stores values when leps varies
MTBFdeps = zeros(3,points);         % Row 3 stores values when ldpt varies
MUTdeps = zeros(3,points);
MDTdeps = zeros(3,points);

% Variable rates
ldpt=linspace(1e-7, 1e-4, points);  % variable failure rate for EPS
leps=linspace(1e-6, 1e-3, points);  % variable failure rate for DPT

% Fixed rates
leps_fix=3.06e-5;           % failure rate for EPS
ldpt_fix=3.28e-6;           % failure rate for DPT 
ld=1e-7;                    % failure rate of the backup EPS when not working
nr=1e5;                     % time to replace EPS by backup EPS: 0.00001 hours = 36 msec
neps=1/6;                   % time to repair eps: 6 hours
ndpt=1/6;                   % time to repair dpt: 6 hours

% Reference values
[Avdeps(1,:) Undeps(1,:) MTBFdeps(1,:) MUTdeps(1,:) MDTdeps(1,:)] = MM_DEPS(ldpt_fix, leps_fix, ld, nr, neps, ndpt);

for j=[1:points]   
       
    [Avdeps(2,j) Undeps(2,j) MTBFdeps(2,j) MUTdeps(2,j) MDTdeps(2,j)] = MM_DEPS(ldpt_fix, leps(1,j), ld, nr, neps, ndpt);
    [Avdeps(3,j) Undeps(3,j) MTBFdeps(3,j) MUTdeps(3,j) MDTdeps(3,j)] = MM_DEPS(ldpt(1,j), leps_fix, ld, nr, neps, ndpt);
   
end

% Graphics for Duplicated EPS
figure
plot(leps, Undeps(2,:), 'b-');
hold on
plot(ldpt, Undeps(3,:), 'k-');
hold on
plot(scale, Undeps(1,:), 'r-');
hold on

title('Unavailabity for Duplicated EPS - Markov Model.');
xlabel('leps, ldpt');
ylabel('Unavailability');
legend('x axis = leps','x axis = dpt', 'Reference = 2.461e-5');
hold on
grid on;

figure
plot(leps, MTBFdeps(2,:), 'b-');
hold on
plot(ldpt, MTBFdeps(3,:), 'k-');
hold on
plot(scale, MTBFdeps(1,:), 'r-');
hold on

title('MTBF (hours) for Duplicated EPS - Markov Model.');
xlabel('leps, ldpt');
ylabel('MTBF (hours)');
legend('x axis = leps','x axis = dpt', 'Reference = 47620');
hold on
grid on;

figure
plot(leps, MDTdeps(2,:), 'b-');
hold on
plot(ldpt, MDTdeps(3,:), 'k-');
hold on
plot(scale, MDTdeps(1,:), 'r-');
hold on

title('MDT (hours) for Duplicated EPS - Markov Model.');
xlabel('leps, ldpt');
ylabel('MDT (hours)');
legend('x axis = leps','x axis = dpt', 'Reference = 1.172');
hold on
grid on;
