
% (Un)Availability values for DAVID Arch. - Block Diagram
% DAVID Architecture for OPS. No signaling between nodes
clear all;
format long;

% Number of wavelengths
M = 32;

% Fixed values for Availability
Aamp_fix = 0.999983;                  % OFC 98  [40]
Asoa_fix = 0.999994;                  % OFC 98  [40]
Areg_fix = 0.99998;                   % Design Strategies...  [48]

% Variable values
Uamp = [1e-7, 1e-6, 1e-5, 1e-4, 1e-3, 1e-2];
Usoa = [1e-7, 1e-6, 1e-5, 1e-4, 1e-3, 1e-2];
Ureg = [1e-7, 1e-6, 1e-5, 1e-4, 1e-3, 1e-2];
Aamp = 1 - Uamp;
Asoa = 1 - Usoa;
Areg = 1 - Ureg;                                

% Availabilities for the 4 models
Adav_amp = zeros(1,6);
Adav_soa = zeros(1,6);
Adav_reg = zeros(1,6);
Adav = zeros(1,6);

% Reference Availability
Adav(1,:) = Areg_fix * Aamp_fix .* (1 - (1-((Asoa_fix^2)*Areg_fix))^M);
Udav = 1-Adav;

% Availabilities varying Aamp, Asoa, Areg
Adav_amp = Areg_fix .* Aamp .* (1 - (1-((Asoa_fix^2)*Areg_fix))^M);
Adav_soa = Areg_fix * Aamp_fix .* (1 - (1-((Asoa.^2).*Areg_fix)).^M);
Adav_reg = Areg .* Aamp_fix .* (1 - (1-((Asoa_fix^2).*Areg)).^M);

Udav_amp = 1 - Adav_amp;
Udav_soa = 1 - Adav_soa;
Udav_reg = 1 - Adav_reg;

% Figure
figure
plot(Uamp, Udav_amp, 'k.-');
hold on
plot(Usoa, Udav_soa, 'bo-');
hold on
plot(Ureg, Udav_reg, 'cx-');
hold on
plot(Ureg, Udav, 'rs-');

title('Unavailability for DAVID Architecture - Block Diagram. No Communication Between Nodes');
xlabel('Uamp, Usoa, Ureg');
ylabel('Unavailability');
legend('x axis = Uamp', 'x axis = Usoa', 'x axis = Ureg', 'Reference = 3.7e-5');
hold off
grid on;