
% (Un)Availability values for DAVID Arch. - Block Diagram
% DAVID Architecture for OPS. Signaling between nodes
clear all;
format long;

% Number of wavelengths
M = 32;

% Fixed values for Availability
Aamp_fix = 0.999983;                  % OFC 98  [40]
Asoa_fix = 0.999994;                  % OFC 98  [40]
Areg_fix = 0.99998;                   % Design Strategies...  [48]

% Variable values
Uamp = [1e-7, 1e-6, 1e-5, 1e-4, 1e-3, 1e-2];
Usoa = [1e-7, 1e-6, 1e-5, 1e-4, 1e-3, 1e-2];
Ureg = [1e-7, 1e-6, 1e-5, 1e-4, 1e-3, 1e-2];
Aamp = 1 - Uamp;
Asoa = 1 - Usoa;
Areg = 1 - Ureg;                                

% Availabilities for the 4 models
Ap_dav_amp = zeros(1,6);
Ap_dav_soa = zeros(1,6);
Ap_dav_reg = zeros(1,6);
Ap_dav = zeros(1,6);

% Reference Availability
Ap_dav(1,:) = (1 - (1-Areg_fix)^M) * Aamp_fix .* (1 - (1-((Asoa_fix^2)*Areg_fix))^M);
Up_dav = 1-Ap_dav;

% Availabilities varying Aamp, Asoa, Areg
Ap_dav_amp = (1 - (1-Areg_fix)^M) .* Aamp .* (1 - (1-((Asoa_fix^2)*Areg_fix))^M);
Ap_dav_soa = (1 - (1-Areg_fix)^M) * Aamp_fix .* (1 - (1-((Asoa.^2).*Areg_fix)).^M);
Ap_dav_reg = (1 - (1-Areg).^M) .* Aamp_fix .* (1 - (1-((Asoa_fix^2).*Areg)).^M);

Up_dav_amp = 1 - Ap_dav_amp;
Up_dav_soa = 1 - Ap_dav_soa;
Up_dav_reg = 1 - Ap_dav_reg;

% Figure
figure
plot(Uamp, Up_dav_amp, 'k.-');
hold on
plot(Usoa, Up_dav_soa, 'bo-');
hold on
plot(Ureg, Up_dav_reg, 'cx-');
hold on
plot(Ureg, Up_dav, 'rs-');

title('Unavailability for DAVID Architecture - Block Diagram. With Communication Between Nodes');
xlabel('Uamp, Usoa, Ureg');
ylabel('Unavailability');
legend('x axis = Uamp', 'x axis = Usoa', 'x axis = Ureg', 'Reference = 1.7e-5');
hold off
grid on;