
% (Un)Availability values for Multiplane Arch. - Block Diagram
% Multiplane Architecture for OPS. Signaling between nodes
clear all;
format long;

% Number of wavelengths
M = 32;

% Fixed values for Availability
Acon_fix = 0.9999779;                    % Calculated
Aawg_fix = 0.9999996;                    % High Utilization... [52]
Atwc_n_fix = 0.99998;                    % Calculated
Atwc_m_fix = 0.999976;                   % Calculated

% Variable values
Ucon = [1e-7, 1e-6, 1e-5, 1e-4, 1e-3, 1e-2];
Uawg = [1e-7, 1e-6, 1e-5, 1e-4, 1e-3, 1e-2];
Utwc_n = [1e-7, 1e-6, 1e-5, 1e-4, 1e-3, 1e-2];
Utwc_m = [1e-7, 1e-6, 1e-5, 1e-4, 1e-3, 1e-2];
Acon = 1 - Ucon;
Aawg = 1 - Uawg;
Atwc_n = 1 - Utwc_n;
Atwc_m = 1 - Utwc_m; 

% Availabilities for the 5 models
Amulplane_con = zeros(1,6);
Amulplane_awg = zeros(1,6);
Amulplane_twc_n = zeros(1,6);
Amulplane_twc_m = zeros(1,6);
Amulplane = zeros(1,6);

% Reference Availability
Amulplane(1,:) = (1 - (1 - Acon_fix * Atwc_n_fix * Aawg_fix * Atwc_m_fix)^M);
Umulplane = 1-Amulplane;

% Availabilities varying Acon, Aawg, Atwc_n, Atwc_m
Amulplane_con = (1 - (1 - Acon .* Atwc_n_fix * Aawg_fix * Atwc_m_fix).^M);
Amulplane_awg = (1 - (1 - Acon_fix * Atwc_n_fix .* Aawg * Atwc_m_fix).^M);
Amulplane_twc_n = (1 - (1 - Acon_fix .* Atwc_n * Aawg_fix * Atwc_m_fix).^M);
Amulplane_twc_m = (1 - (1 - Acon_fix * Atwc_n_fix * Aawg_fix .* Atwc_m).^M);

Umulplane_con = 1 - Amulplane_con;
Umulplane_awg = 1 - Amulplane_awg;
Umulplane_twc_n = 1 - Amulplane_twc_n;
Umulplane_twc_m = 1 - Amulplane_twc_m;

% Figure
figure
plot(Ucon, Umulplane_con, 'm.-');
hold on
plot(Uawg, Umulplane_awg, 'k.-');
hold on
plot(Utwc_n, Umulplane_twc_n, 'bo-');
hold on
plot(Utwc_m, Umulplane_twc_m, 'gx-');
hold on
plot(Ucon, Umulplane, 'rs-');
hold on

title('Unavailability for Multiplane Architecture - Block Diagram. With Communication Between Nodes');
xlabel('Ucon, Uawg, Utwc_n, Utwc_m');
ylabel('Unavailability');
legend('x axis = Ucon', 'x axis = Uawg', 'x axis = Utwc_n', 'x axis = Utwc_m', 'Reference = 0');
hold off
grid on;