
% (Un)Availability values for Multiport Arch. - Block Diagram
% Multiport Architecture for OPS. No signaling between nodes
clear all;
format long;

% Number of wavelengths
M = 32;

% Fixed values for Availability
Aawg_fix = 0.9999996;                    % High Utilization... [52]
Atwc_nm_fix = 0.99997;                   % Calculated
Afwc_fix = 0.999984;                     % Calculated

% Variable values
Uawg = [1e-7, 1e-6, 1e-5, 1e-4, 1e-3, 1e-2];
Utwc_nm = [1e-7, 1e-6, 1e-5, 1e-4, 1e-3, 1e-2];
Ufwc = [1e-7, 1e-6, 1e-5, 1e-4, 1e-3, 1e-2];
Aawg = 1 - Uawg;
Atwc_nm = 1 - Utwc_nm;
Afwc = 1 - Ufwc; 

% Availabilities for the 4 models
Amulport_awg = zeros(1,6);
Amulport_twc_nm = zeros(1,6);
Amulport_fwc = zeros(1,6);
Amulport = zeros(1,6);

% Reference Availabilty
Amulport(1,:) = Atwc_nm_fix * Aawg_fix * (1 - (1 - Afwc_fix)^M);
Umulport = 1-Amulport;

% Availabilities varying Aawg, Atwc_nm, Afwc
Amulport_awg = Atwc_nm_fix .* Aawg * (1 - (1 - Afwc_fix)^M);
Amulport_twc_nm = Atwc_nm .* Aawg_fix * (1 - (1 - Afwc_fix)^M);
Amulport_fwc = Atwc_nm_fix * Aawg_fix .* (1 - (1 - Afwc).^M);

Umulport_awg = 1 - Amulport_awg;
Umulport_twc_nm = 1 - Amulport_twc_nm;
Umulport_fwc = 1 - Amulport_fwc;

% Figure
figure
plot(Uawg, Umulport_awg, 'k.-');
hold on
plot(Utwc_nm, Umulport_twc_nm, 'bo-');
hold on
plot(Ufwc, Umulport_fwc, 'gx-');
hold on
plot(Ufwc, Umulport_fwc, 'rs-');
hold on

title('Unavailability for Multiport Architecture - Block Diagram. No Communication Between Nodes');
xlabel('Uawg, Utwc_nm, Ufwc');
ylabel('Unavailability');
legend('x axis = Uawg', 'x axis = Utwc_nm', 'x axis = Ufwc', 'Reference = 3.04e-5');
hold off
grid on;