
% (Un)Availability values for Multiport Arch. - Block Diagram
% Multiport Architecture for OPS. Signaling between nodes
clear all;
format long;

% Number of wavelengths
M = 32;

% Fixed values for Availability
Aawg_fix = 0.9999996;                    % High Utilization... [52]
Atwc_nm_fix = 0.99997;                   % Calculated
Afwc_fix = 0.999984;                     % Calculated

% Variable values
Uawg = [1e-7, 1e-6, 1e-5, 1e-4, 1e-3, 1e-2];
Utwc_nm = [1e-7, 1e-6, 1e-5, 1e-4, 1e-3, 1e-2];
Ufwc = [1e-7, 1e-6, 1e-5, 1e-4, 1e-3, 1e-2];
Aawg = 1 - Uawg;
Atwc_nm = 1 - Utwc_nm;
Afwc = 1 - Ufwc; 

% Availabilities for the 4 models
Ap_mulport_awg = zeros(1,6);
Ap_mulport_twc_nm = zeros(1,6);
Ap_mulport_fwc = zeros(1,6);
Ap_mulport = zeros(1,6);

% Reference Availability
Ap_mulport(1,:) = (1 - (1 - Atwc_nm_fix)^M) * Aawg_fix * (1 - (1 - Afwc_fix)^M);
Up_mulport = 1-Ap_mulport;

% Availabilities varying Aawg, Atwc_nm, Afwc
Ap_mulport_awg = (1 - (1 - Atwc_nm_fix)^M) .* Aawg * (1 - (1 - Afwc_fix)^M);
Ap_mulport_twc_nm = (1 - (1 - Atwc_nm).^M) .* Aawg_fix * (1 - (1 - Afwc_fix)^M);
Ap_mulport_fwc = (1 - (1 - Atwc_nm_fix)^M) * Aawg_fix .* (1 - (1 - Afwc).^M);

Up_mulport_awg = 1 - Ap_mulport_awg;
Up_mulport_twc_nm = 1 - Ap_mulport_twc_nm;
Up_mulport_fwc = 1 - Ap_mulport_fwc;

% Figure
figure
plot(Uawg, Up_mulport_awg, 'k.-');
hold on
plot(Utwc_nm, Up_mulport_twc_nm, 'bo-');
hold on
plot(Ufwc, Up_mulport_fwc, 'gx-');
hold on
plot(Ufwc, Up_mulport_fwc, 'rs-');
hold on

title('Unavailability for Multiport Architecture - Block Diagram. With Communication Between Nodes');
xlabel('Uawg, Utwc_nm, Ufwc');
ylabel('Unavailability');
legend('x axis = Uawg', 'x axis = Utwc_nm', 'x axis = Ufwc', 'Reference = 4e-7');
hold off
grid on;