
% (Un)Availability values for OpMiGua Arch. - Block Diagram
% OpMiGua Architecture for OPS. No signaling between nodes
clear all;
format long;

% Number of wavelengths
M = 32;

% Fixed values for Availability
Aawg_fix = 0.9999996;                    % High Utilization... [52]
Atwc_m_fix = 0.999976;                   % Calculated

% Variable values
Uawg = [1e-7, 1e-6, 1e-5, 1e-4, 1e-3, 1e-2];
Utwc_m = [1e-7, 1e-6, 1e-5, 1e-4, 1e-3, 1e-2];
Aawg = 1 - Uawg;
Atwc_m = 1 - Utwc_m;                                

% Availabilities for the 3 models
Aop_awg = zeros(1,6);
Aop_twc_m = zeros(1,6);
Aop = zeros(1,6);

% Reference Availability
Aop(1,:) = Atwc_m_fix * (1 - (1 - Atwc_m_fix)^M) * Aawg_fix;
Uop = 1-Aop;

% Availabilities varying Aawg, Atwc_m
Aop_awg = Atwc_m_fix * (1 - (1 - Atwc_m_fix)^M) .* Aawg;
Aop_twc_m = Atwc_m .* (1 - (1 - Atwc_m).^M) * Aawg_fix;

Uop_awg = 1 - Aop_awg;
Uop_twc_m = 1 - Aop_twc_m;

% Figure
figure
plot(Uawg, Uop_awg, 'k.-');
hold on
plot(Utwc_m, Uop_twc_m, 'bo-');
hold on
plot(Utwc_m, Uop, 'rs-');

title('Unavailability for OpMiGua Architecture - Block Diagram. No Communication Between Nodes');
xlabel('Uawg, Utwc_m');
ylabel('Unavailability');
legend('x axis = Uawg', 'x axis = Utwc_m', 'Reference = 2.44e-5');
hold off
grid on;