
% (Un)Availability values for OpMiGua Arch. - Block Diagram
% OpMiGua Architecture for OPS. Signaling between nodes
clear all;
format long;

% Number of wavelengths
M = 32;

% Fixed values for Availability
Aawg_fix = 0.9999996;                 % High Utilization... [52]
Atwc_m_fix = 0.999976;                % Calculated

% Variable values
Uawg = [1e-7, 1e-6, 1e-5, 1e-4, 1e-3, 1e-2];
Utwc_m = [1e-7, 1e-6, 1e-5, 1e-4, 1e-3, 1e-2];
Aawg = 1 - Uawg;
Atwc_m = 1 - Utwc_m;                                

% Availabilities for the 3 models
Ap_op_awg = zeros(1,6);
Ap_op_twc_m = zeros(1,6);
Ap_op = zeros(1,6);

% Reference Availability
Ap_op(1,:) = (1 - (1 - Atwc_m_fix)^M) * (1 - (1 - Atwc_m_fix)^M) * Aawg_fix;
Up_op = 1-Ap_op;

% Availabilities varying Aawg, Atwc_m
Ap_op_awg = (1 - (1 - Atwc_m_fix)^M) * (1 - (1 - Atwc_m_fix)^M) .* Aawg;
Ap_op_twc_m = (1 - (1 - Atwc_m).^M) .* (1 - (1 - Atwc_m).^M) * Aawg_fix;

Up_op_awg = 1 - Ap_op_awg;
Up_op_twc_m = 1 - Ap_op_twc_m;

% Figure
figure
plot(Uawg, Up_op_awg, 'k.-');
hold on
plot(Utwc_m, Up_op_twc_m, 'bo-');
hold on
plot(Utwc_m, Up_op, 'rs-');

title('Unavailability for OpMiGua Architecture - Block Diagram. With Communication Between Nodes');
xlabel('Uawg, Utwc_m');
ylabel('Unavailability');
legend('x axis = Uawg', 'x axis = Utwc_m', 'Reference = 4e-7');
hold off
grid on;