
% (Un)Availability values for TAS Arch. - Block Diagram
% DAVID Architecture for OPS. No signaling between nodes
clear all;
format long

% Number of wavelengths
M = 32;

% Fixed values for Availability
Aamp_fix = 0.999983;                  % OFC 98  [40]
Asoa_fix = 0.999994;                  % OFC 98  [40]
Atwc_m_fix = 0.999976;                % Calculated

% Variable values
Uamp = [1e-7, 1e-6, 1e-5, 1e-4, 1e-3, 1e-2];
Usoa = [1e-7, 1e-6, 1e-5, 1e-4, 1e-3, 1e-2];
Utwc_m = [1e-7, 1e-6, 1e-5, 1e-4, 1e-3, 1e-2];
Aamp = 1 - Uamp;
Asoa = 1 - Usoa;
Atwc_m = 1 - Utwc_m;                                

% Availabilities for the 4 models
Atas_amp = zeros(1,6);
Atas_soa = zeros(1,6);
Atas_twc_m = zeros(1,6);
Atas = zeros(1,6);

Atas(1,:) = Aamp_fix * Atwc_m_fix * Asoa_fix *Aamp_fix;
Utas = 1-Atas;

% Availabilities varying Aamp, Asoa, Atwc_m
Atas_amp = Aamp .* Atwc_m_fix * Asoa_fix .* Aamp;
Atas_soa = Aamp_fix * Atwc_m_fix .* Asoa *Aamp_fix;
Atas_twc_m = Aamp_fix .* Atwc_m * Asoa_fix *Aamp_fix;

Utas_amp = 1 - Atas_amp;
Utas_soa = 1 - Atas_soa;
Utas_twc_m = 1 - Atas_twc_m;

% Figure
figure
plot(Uamp, Utas_amp, 'k.-');
hold on
plot(Usoa, Utas_soa, 'bo-');
hold on
plot(Utwc_m, Utas_twc_m, 'cx-');
hold on
plot(Utwc_m, Utas, 'rs-');

title('Unavailability for TAS Architecture - Block Diagram. No Communication Between Nodes');
xlabel('Uamp, Usoa, Utwc_m');
ylabel('Unavailability');
legend('x axis = Uamp', 'x axis = Usoa', 'x axis = Utwc_m', 'Reference = 6.4e-5');
hold off
grid on;