
% (Un)Availability values for TAS Arch. - Block Diagram
% TAS Architecture for OPS. Signaling between nodes
clear all;
format long

% Number of wavelengths
M = 32;

% Fixed values for Availability
Aamp_fix = 0.999983;                  % OFC 98  [40]
Asoa_fix = 0.999994;                  % OFC 98  [40]
Atwc_m_fix = 0.999976;                % Calculated

% Variable values
Uamp = [1e-7, 1e-6, 1e-5, 1e-4, 1e-3, 1e-2];
Usoa = [1e-7, 1e-6, 1e-5, 1e-4, 1e-3, 1e-2];
Utwc_m = [1e-7, 1e-6, 1e-5, 1e-4, 1e-3, 1e-2];
Aamp = 1 - Uamp;
Asoa = 1 - Usoa;
Atwc_m = 1 - Utwc_m;                                

% Availabilities for the 4 models
Ap_tas_amp = zeros(1,6);
Ap_tas_soa = zeros(1,6);
Ap_tas_twc_m = zeros(1,6);
Ap_tas = zeros(1,6);

% Reference Availability
Ap_tas(1,:) = Aamp_fix * (1 - (1 - (Atwc_m_fix * Asoa_fix))^M) *Aamp_fix;
Up_tas = 1-Ap_tas;

% Availabilities varying Aamp, Asoa, Atwc_m
Ap_tas_amp = Aamp .* (1 - (1 - (Atwc_m_fix * Asoa_fix))^M) .* Aamp;
Ap_tas_soa = Aamp_fix .* (1 - (1 - (Atwc_m_fix .* Asoa)).^M) * Aamp_fix;
Ap_tas_twc_m = Aamp_fix .* (1 - (1 - (Atwc_m .* Asoa_fix)).^M) * Aamp_fix;

Up_tas_amp = 1 - Ap_tas_amp;
Up_tas_soa = 1 - Ap_tas_soa;
Up_tas_twc_m = 1 - Ap_tas_twc_m;

% Figure
figure
plot(Uamp, Up_tas_amp, 'k.-');
hold on
plot(Usoa, Up_tas_soa, 'bo-');
hold on
plot(Utwc_m, Up_tas_twc_m, 'cx-');
hold on
plot(Utwc_m, Up_tas, 'rs-');

title('Unavailability for TAS Architecture - Block Diagram. With Communication Between Nodes');
xlabel('Uamp, Usoa, Utwc_m');
ylabel('Unavailability');
legend('x axis = Uamp', 'x axis = Usoa', 'x axis = Utwc_m', 'Reference = 3.4e-5');
hold off
grid on;