
% (Un)Availability values for Duplicated OPS - Block Diagram.
% Signaling between nodes allowed
clear all;
format long;

% Number of wavelengths
M = 32;

% Fixed values for Availability
Amux_fix = 0.9999952;                   % [39] based on [40] 
Adpt_fix = 0.99998;                     % Calculated
Asplit_fix = 0.9999999;                 % High Utilization of... [52]
Aops_fix = 0.995;                       % Calculated
Aswitch_fix = 0.9999996;                % High Utilization of... [52]

Aopstot_fix = (1-(1-Aops_fix)^2);
Ap_coup_fix = (1-(1-Asplit_fix)^M);
Ap_dpt_fix = (1-(1-Adpt_fix)^M);

% Variable values
Umux = [1e-7, 1e-6, 1e-5, 1e-4, 1e-3, 1e-2];
Udpt = [1e-7, 1e-6, 1e-5, 1e-4, 1e-3, 1e-2];
Usplit = [1e-7, 1e-6, 1e-5, 1e-4, 1e-3, 1e-2];
Uops = [1e-7, 1e-6, 1e-5, 1e-4, 1e-3, 1e-2];
Uswitch = [1e-7, 1e-6, 1e-5, 1e-4, 1e-3, 1e-2];
Amux = 1 - Umux;
Adpt = 1 - Udpt;
Asplit = 1 - Usplit;
Aops = 1 - Uops;
Aswitch = 1 - Uswitch;

Aopstot = (1-(1-Aops).^2);
Ap_coup = (1-(1-Asplit).^M);
Ap_dpt = (1-(1-Adpt).^M);

% Reference Availability
A1a = zeros(1,6);
A1a(1,:) = Amux_fix * Ap_dpt_fix * Amux_fix * Asplit_fix * Aopstot_fix * Aswitch_fix * Amux_fix * Ap_coup_fix * Amux_fix;
U1a = 1 - A1a;

% Availabilities varying Amux, Adpt, Aspli, Aops, Aswitch
A1a_mux = Amux .* Ap_dpt_fix .* Amux .* Asplit_fix .* Aopstot_fix .* Aswitch_fix .* Amux .* Ap_coup_fix .* Amux;
A1a_dpt = Amux_fix .* Ap_dpt .* Amux_fix * Asplit_fix * Aopstot_fix * Aswitch_fix * Amux_fix * Ap_coup_fix * Amux_fix;
A1a_split = Amux_fix * Ap_dpt_fix * Amux_fix .* Asplit .* Aopstot_fix * Aswitch_fix * Amux_fix .* Ap_coup .* Amux_fix;
A1a_ops = Amux_fix * Ap_dpt_fix * Amux_fix * Asplit_fix .* Aopstot .* Aswitch_fix * Amux_fix * Ap_coup_fix * Amux_fix;
A1a_switch = Amux_fix * Ap_dpt_fix * Amux_fix * Asplit_fix * Aopstot_fix .* Aswitch .* Amux_fix * Ap_coup_fix * Amux_fix;

U1a_mux = 1 - A1a_mux;
U1a_dpt = 1 - A1a_dpt;
U1a_split = 1 - A1a_split;
U1a_ops = 1 - A1a_ops;
U1a_switch = 1 - A1a_switch;

%Figure
figure
plot(Umux, U1a_mux, 'bo-');
hold on;
plot(Udpt, U1a_dpt, 'cx-');
hold on;
plot(Usplit, U1a_split, 'ys-');
hold on;
plot(Uops, U1a_ops, 'm*-');
hold on
plot(Uswitch, U1a_switch, 'k+-');
hold on
plot(Uswitch, U1a, 'rs-');
hold on;

title('Unavailability for Duplicated OPS - Block Diagram. With Communication Between Nodes');
xlabel('Umux, Udpt, Usplit, Uops, Uswitch');
ylabel('Unavailability');
legend('x axis = Umux', 'x axis = Udpt', 'x axis = Usplit', 'x axis = Uops', 'x axis = Uswitch', 'Reference = 4.47e-5');
hold off
grid on;
