
% (Un)Availability values for Reroute EPS - Block Diagram.
% No signaling between nodes
clear all;
format long;

% Number of wavelengths
M = 32;

% Fixed values for Availability
Amux_fix = 0.9999952;                   % [39] based on [40] 
Adpt2_fix = 0.999976;                   % Calculated
Asplit_fix = 0.9999999;                 % High Utilization of... [52]
Aops_fix = 0.995;                       % Calculated
Aeps_fix = 0.999816;                    % Calculated

Aopseps_fix = (1-((1-Aops_fix)*(1-Aeps_fix)));
Ap_coup_fix = (1-(1-Asplit_fix)^M);

% Variable values
Umux = [1e-7, 1e-6, 1e-5, 1e-4, 1e-3, 1e-2];
Udpt2 = [1e-7, 1e-6, 1e-5, 1e-4, 1e-3, 1e-2];
Usplit = [1e-7, 1e-6, 1e-5, 1e-4, 1e-3, 1e-2];
Uops = [1e-7, 1e-6, 1e-5, 1e-4, 1e-3, 1e-2];
Ueps = [1e-7, 1e-6, 1e-5, 1e-4, 1e-3, 1e-2];
Amux = 1 - Umux;
Adpt2 = 1 - Udpt2;
Asplit = 1 - Usplit;
Aops = 1 - Uops;
Aeps = 1 - Ueps;

Aopseps_o = (1-((1-Aops).*(1-Aeps_fix)));
Aopseps_e = (1-((1-Aops_fix).*(1-Aeps)));
Ap_coup = (1-(1-Asplit).^M);

% Reference Availability
A2b = zeros(1,6);
A2b(1,:) = Amux_fix * Adpt2_fix * Aopseps_fix * Ap_coup_fix * Amux_fix;
U2b = 1 - A2b;

% Availabilities varying Amux, Adpt, Aspli, Aops, Aeps
A2b_mux = Amux .* Adpt2_fix * Aopseps_fix .* Ap_coup_fix .* Amux;
A2b_dpt2 = Amux_fix .* Adpt2 .* Aopseps_fix * Ap_coup_fix * Amux_fix;
A2b_split = Amux_fix * Adpt2_fix * Aopseps_fix .* Ap_coup .* Amux_fix;
A2b_ops = Amux_fix * Adpt2_fix .* Aopseps_o .* Ap_coup_fix * Amux_fix;
A2b_eps = Amux_fix * Adpt2_fix .* Aopseps_e .* Ap_coup_fix * Amux_fix;

U2b_mux = 1 - A2b_mux;
U2b_dpt2 = 1 - A2b_dpt2;
U2b_split = 1 - A2b_split;
U2b_ops = 1 - A2b_ops;
U2b_eps = 1 - A2b_eps;

%Figure
figure
plot(Umux, U2b_mux, 'bo-');
hold on;
plot(Udpt2, U2b_dpt2, 'cx-');
hold on;
plot(Usplit, U2b_split, 'ys-');
hold on;
plot(Uops, U2b_ops, 'm*-');
hold on
plot(Ueps, U2b_eps, 'k+-');
hold on
plot(Umux, U2b, 'rs-');
hold on;

title('Unavailability for Reroute EPS - Block Diagram. No Communication Between Nodes');
xlabel('Umux, Udpt2, Usplit, Uops, Ueps');
ylabel('Unavailability');
legend('x axis = Umux', 'x axis = Udpt2', 'x axis = Usplit', 'x axis = Uops', 'x axis = Ueps', 'Reference = 3.415e-5');
hold off
grid on;