% (Un)Availability values for Reroute EPS - Combined Model.
% Parameters of the input subsystem have to be changed in Fig_Input_REPS
% Parameters of the OPSEPS subsystem have to be changed in Fig_OPSEPS_REPS
% Parameters of the output subsystem have to be changed in Fig_Output_REPS
clear all;
format long;

% Fig_Input_REPS and Fig_Output_REPS calculate A of the input and output
% for 5 different values of c = 0.7, 0.775, 0.85, 0.925, 1
% and k varying from 1 to 32. The other parameters are fixed
% Fig_OPSEPS_REPS calculates A of the OPSEPS subsystem for the 5
% values of c, and lops varying from 1e-5 to 1e-2. The other parameters are
% fixed
% Also figures are generated
Fig_Input_REPS                
Fig_OPSEPS_REPS
Fig_Output_REPS

% Matrix to store the total Availability. 
A = zeros(6,points_l);

% Calculating total availability.
% Al_input has the As of the input and Al_out has the As of the output
% for different values of c and k
% Each row corresponds to a value of c: row 1 -> c=0.7; row 2 -> c=0.775 ..
% Each column corresponds to a value of k: col 1 -> k=1; col 32 -> k=32 ...
% Al_OPSEPS has the As of the OPSEPS subsystem for different values of c and lops
% Each row correspond to a value of c, 
% Each column corresponds to a value of lops

% The following line calculates Ainput x Aoutput for all ks (all columns), with
% c_input=0.775 (row 2) and c_output=0.925 (row 4)
Aio = Al_input (2,:) .* Al_out (4,:);                    

% The following lines calculate the total A for k=1,10,20,30,31,32,
% c_input=0.775, c_output=0.925, c_opseps=0.85 and lops varying from 1e-5
% to 1e-2 (all columns of Al_OPSEPS)
A(1, :) = Aio(1,1) * Al_OPSEPS(3,:);
A(2, :) = Aio(1,10) * Al_OPSEPS(3,:);
A(3, :) = Aio(1,20) * Al_OPSEPS(3,:);
A(4, :) = Aio(1,30) * Al_OPSEPS(3,:);
A(5, :) = Aio(1,31) * Al_OPSEPS(3,:);
A(6, :) = Aio(1,32) * Al_OPSEPS(3,:);

U = 1-A;

figure
plot(lops, U(1,:), 'b.-');
hold on
plot(lops, U(2,:), 'r.-');
hold on
plot(lops, U(3,:), 'g.-');
hold on
plot(lops, U(4,:), 'y.-');
hold on
plot(lops, U(5,:), 'k.-');
hold on
plot(lops, U(6,:), 'm.-');
hold on
grid on

title('Unavailabity for Reroute EPS - Combined Model.');
xlabel('lops');
ylabel('Unavailability');
legend('k = 1','k = 10','k = 20','k = 30', 'k = 31', 'k = 32');