
% Script for Figures Input Reroute EPS
points_c=5;                 % number of c values
points_k=32;                % number of k values 

% Parameter values
l = 4e-6;                         % failure rate DPT when rerouting to EPS
n = 1/6;                            % time to repair dpt: 6 hours
nc = 1/12;                          % Fix failure system: 12 horas
k = linspace(1, 32, points_k);      % k varies from 1 to 32
c = linspace(0.7, 1, points_c);     % c has 5 values
N = 32;                             % Number of wavelengths

% Matrixes for data
Al_input = zeros(points_c, points_k);      
Ul_input = zeros(points_c, points_k);

% Calling the function that solves the Markov Model of the input subsystem
for j=1:1:points_c
    for a=1:1:points_k
        [Al_input(j,a) Ul_input(j,a)] = Input_REPS(l,n,nc,k(a),c(j),N);
    end
end

% Graphs
figure
plot(k, Ul_input(1,:), 'b.-');
hold on
plot(k, Ul_input(2,:), 'r.-');
hold on
plot(k, Ul_input(3,:), 'g.-');
hold on
plot(k, Ul_input(4,:), 'y.-');
hold on
plot(k, Ul_input(5,:), 'k.-');
hold on
grid on

title('Unavailabity for Reroute EPS - Combined Model. Input Subsystem Unavailability');
xlabel('k');
ylabel('Unavailability');
legend('c = 0.7','c = 0.775','c = 0.85','c = 0.925', 'c = 1');
