
% Script for OPSEPS Reroute EPS
points_c=5;             % number of c values
points_l=100;           % number of lops values    

% Parameter values
lops = linspace(1e-5, 1e-2, points_l);  % OPS failure rate
leps = 3.06e-5;                          % EPS failure rate
nops = 1/6;                             % time to repair ops: 6 hours
neps = 1/6;                             % time to repair eps: 6 hours
n2 = 1/4;                               % Fix failure system & change OPS 4 h
c = linspace(0.7, 1, points_c);         % c has 5 values

% Matrixes for data
Al_OPSEPS = zeros(points_c, 1);      
Ul_OPSEPS = zeros(points_c, 1);

% Calling the function function that solves the Markov Model of the
% OPSEPS subsystem
for j=1:1:points_c
    for a=1:1:points_l        
        [Al_OPSEPS(j,a) Ul_OPSEPS(j,a)] = OPSEPS_REPS(lops(a),leps,nops,neps,n2,c(j));
    end
end

% Graphs
figure
plot(lops, Ul_OPSEPS(1,:), 'b.-');
hold on
plot(lops, Ul_OPSEPS(2,:), 'r.-');
hold on
plot(lops, Ul_OPSEPS(3,:), 'g.-');
hold on
plot(lops, Ul_OPSEPS(4,:), 'y.-');
hold on
plot(lops, Ul_OPSEPS(5,:), 'k.-');
hold on
grid on

title('Unavailabity for Reroute EPS - Combined Model. OPSEPS Sybsystem Unavailability');
xlabel('lops');
ylabel('Unavailability');
legend('c = 0.7','c = 0.775','c = 0.85','c = 0.925', 'c = 1');
