% Markov Model for Reroute EPS
function [A U MTBF MUT MDT] = MM_REPS(ldpt, lops, leps, nre, nops, ndpt, neps)
format long;
format long;

% Simbolic variables
%syms ldpt lops leps nre nops ndpt neps;
syms p1 p2 p3 p4 p5 p6 p7 p8 p9 p10;

% Transition Intensity Matrix
Q = [ -ldpt-lops-leps, lops, 0, 0, leps, ldpt, 0, 0, 0, 0;
    0, -ldpt-leps-nre, leps, nre, 0, 0, ldpt, 0, 0, 0;
    0, 0, -nops-ldpt, 0, nops, 0, 0, 0, 0, ldpt;
    nops, 0, leps, -nops-leps-ldpt, 0, 0, 0, 0, ldpt, 0;
    neps, 0, lops, 0, -ldpt-lops-neps, 0, 0, ldpt, 0, 0;
    ndpt, 0, 0, 0, 0, -ndpt-leps-lops, lops, leps, 0, 0;
    0, ndpt, 0, 0, 0, 0, -ndpt-leps, 0, 0, leps;
    0, 0, 0, 0, ndpt, 0, 0, -ndpt-lops, 0, lops;
    0, 0, 0, ndpt, 0, 0, 0, 0, -ndpt-leps, leps;
    0, 0, ndpt, 0, 0, 0, 0, 0, 0, -ndpt];

% Vector with probabilities
p = [p1, p2, p3, p4, p5, p6, p7, p8, p9, p10];

% Equilibrium equations
f1 = p*Q(:,1);
f2 = p*Q(:,2);
f3 = p*Q(:,3);
f4 = p*Q(:,4);
f5 = p*Q(:,5);
f6 = p*Q(:,6);
f7 = p*Q(:,7);
f8 = p*Q(:,8);
f9 = p*Q(:,9);
f10 = p*Q(:,10);
% Normalization Ecuation
f11 = p1 + p2 + p3 + p4 + p5 + p6 + p7 + p8 + p9 + p10 - 1;

% Solving the system 
S = solve(f1, f2, f3, f4, f5, f6, f7, f8, f9, f11, 'p1, p2, p3, p4, p5, p6, p7, p8, p9, p10');
p1 = S.p1;
p2 = S.p2;
p3 = S.p3;
p4 = S.p4;
p5 = S.p5;
p6 = S.p6;
p7 = S.p7;
p8 = S.p8;
p9 = S.p9;
p10 = S.p10;

% Availability and Unavailability
A = eval(p1 + p4 + p5);
U = eval(p2 + p3 + p6 + p7 + p8 + p9 + p10);

%[Us, HOW] = simple(U);
%pretty(Us);

% Sistem failure intensity
SFI = Q(1,2)*p1 + Q(1,6)*p1 + Q(4,3)*p4 + Q(4,9)*p4 + Q(5,3)*p5 + Q(5,8)*p5;

% System Times
MTBF = eval(1/SFI);
MUT = A*MTBF;
MDT = U*MTBF;