% (Un)Availability values for Duplicated OPS VS Reroute to EPS - Markov Model.
% 1 DPT, 2 OPS vs 1 DPT, 1 OPS, 1 EPS.

points= 100; %Number of points
scale=linspace(1e-7, 1e-2, points); % Used to plot the reference line in figures

Avdops = zeros(3,points);           % Row 1 stores reference value (all rates fixed)
Undops = zeros(3,points);           % Row 2 stores values when lops varies
MTBFdops = zeros(3,points);         % Row 3 stores values when ldpt varies
MUTdops = zeros(3,points);
MDTdops = zeros(3,points);

Avreps = zeros(4,points);           % Row 1 stores reference value (all rates fixed)
Unreps = zeros(4,points);           % Row 2 stores values when lops varies
MTBFreps = zeros(4,points);         % Row 3 stores values when ldpt varies
MUTreps = zeros(4,points);          % Row 4 stores values when leps varies
MDTreps = zeros(4,points);

% Variable rates
lops=linspace(1e-5, 1e-2, points);  % variable failure rate for OPS
ldpt=linspace(1e-7, 1e-4, points);  % variable failure rate for DPT
leps=linspace(1e-6, 1e-3, points);  % variable failure rate for EPS


% Fixed rates
lops_fix=8.375e-4;          % failure rate for OPS
leps_fix=3.06e-5;           % failure rate for EPS
ldpt1_fix=3.28e-6;          % DPT in duplicated OPS
ldpt2_fix=4e-6;             % DPT in Rerouted traffic to EPS 
ld=1e-5;                    % failure rate of the backup OPS when not working
nr=1e5;                     % time to replace OPS by backup OPS: 0.00001 hours = 36 msec
nre=nr;                     % time to replace OPS by EPS
nops=1/6;                   % time to repair ops: 6 hours
neps=1/6;                   % time to repair eps: 6 hours
ndpt=1/6;                   % time to repair dpt: 6 hours

% Reference values
[Avdops(1,:) Undops(1,:) MTBFdops(1,:) MUTdops(1,:) MDTdops(1,:)] = MM_DOPS(ldpt1_fix, lops_fix, ld, nr, nops, ndpt);
[Avreps(1,:) Unreps(1,:) MTBFreps(1,:) MUTreps(1,:) MDTreps(1,:)] = MM_REPS(ldpt2_fix, lops_fix, leps_fix, nre, nops, ndpt, neps);

for j=[1:points]   
       
    [Avdops(2,j) Undops(2,j) MTBFdops(2,j) MUTdops(2,j) MDTdops(2,j)] = MM_DOPS(ldpt1_fix, lops(1,j), ld, nr, nops, ndpt);
    [Avdops(3,j) Undops(3,j) MTBFdops(3,j) MUTdops(3,j) MDTdops(3,j)] = MM_DOPS(ldpt(1,j), lops_fix, ld, nr, nops, ndpt);
    
    [Avreps(2,j) Unreps(2,j) MTBFreps(2,j) MUTreps(2,j) MDTreps(2,j)] = MM_REPS(ldpt2_fix, lops(1,j), leps_fix, nre, nops, ndpt, neps);
    [Avreps(3,j) Unreps(3,j) MTBFreps(3,j) MUTreps(3,j) MDTreps(3,j)] = MM_REPS(ldpt(1,j), lops_fix, leps_fix, nre, nops, ndpt, neps);   
    [Avreps(4,j) Unreps(4,j) MTBFreps(4,j) MUTreps(4,j) MDTreps(4,j)] = MM_REPS(ldpt2_fix, lops_fix, leps(1,j), nre, nops, ndpt, neps);
    
end

% Graphics for Duplicated OPS
figure
plot(lops, Undops(2,:), 'b-');
hold on
plot(ldpt, Undops(3,:), 'k-');
hold on
plot(scale, Undops(1,:), 'r-');
hold on

title('Unavailabity for Duplicated OPS - Markov Model.');
xlabel('lops, ldpt');
ylabel('Unavailability');
legend('x axis = lops','x axis = dpt', 'Reference = 1.076e-4');
hold on
grid on;

figure
plot(lops, MTBFdops(2,:), 'b-');
hold on
plot(ldpt, MTBFdops(3,:), 'k-');
hold on
plot(scale, MTBFdops(1,:), 'r-');
hold on

title('MTBF (hours) for Duplicated OPS - Markov Model.');
xlabel('lops, ldpt');
ylabel('MTBF (hours)');
legend('x axis = lops','x axis = dpt', 'Reference = 1135');
hold on
grid on;

figure
plot(lops, MDTdops(2,:), 'b-');
hold on
plot(ldpt, MDTdops(3,:), 'k-');
hold on
plot(scale, MDTdops(1,:), 'r-');
hold on

title('MDT (hours) for Duplicated OPS - Markov Model.');
xlabel('lops, ldpt');
ylabel('MDT (hours)');
legend('x axis = lops','x axis = dpt', 'Reference = 0.1221');
hold on
grid on;

% Graphics for Reroute EPS
figure
plot(lops, Unreps(2,:), 'b-');
hold on
plot(ldpt, Unreps(3,:), 'k-');
hold on
plot(leps, Unreps(4,:), 'g-');
hold on
plot(scale, Unreps(1,:), 'r-');
hold on

title('Unavailabity for Reroute EPS - Markov Model.');
xlabel('lops, ldpt, leps');
ylabel('Unavailability');
legend('x axis = lops','x axis = dpt', 'x axis = leps', 'Reference = 2.508e-5');
hold on
grid on;

figure
plot(lops, MTBFreps(2,:), 'b-');
hold on
plot(ldpt, MTBFreps(3,:), 'k-');
hold on
plot(leps, MTBFreps(4,:), 'g-');
hold on
plot(scale, MTBFreps(1,:), 'r-');
hold on

title('MTBF (hours) for Reroute EPS - Markov Model.');
xlabel('lops, ldpt, leps');
ylabel('MTBF (hours)');
legend('x axis = lops','x axis = dpt', 'x axis = leps', 'Reference = 1140');
hold on
grid on;

figure
plot(lops, MDTreps(2,:), 'b-');
hold on
plot(ldpt, MDTreps(3,:), 'k-');
hold on
plot(leps, MDTreps(4,:), 'g-');
hold on
plot(scale, MDTreps(1,:), 'r-');
hold on

title('MDT (hours) for Reroute EPS - Markov Model.');
xlabel('lops, ldpt, leps');
ylabel('MDT (hours)');
legend('x axis = lops','x axis = dpt', 'x axis = leps', 'Reference = 0.0286');
hold on
grid on;
